/*
 * Created on 2005/01/23
 *
 */
package jnet.application.gui;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import javax.swing.JMenuBar;
import javax.swing.JTabbedPane;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import jnet.htk.gui.HTKMainWindow;
/**
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class MainWindow extends JFrame {
	
	/**
	 * size of window
	 */
	public  static final int WINDOW_HEIGHT = 350;
	
	/**
	 * size of window
	 */
	public  static final int WINDOW_WIDTH = 250;
	
	/**
	 * This is a look and feel.
	 * <br>
	 * 0:Windows<br>
	 * 1:Metal<br>
	 * 2:GTK<br>
	 * 3:Motifi<br>
	 * 4:Mac<br>
	 */
	private String[] lookAndFeelStr = {"com.sun.java.swing.plaf.windows.WindowsLookAndFeel",
										"javax.swing.plaf.metal.MetalLookAndFeel",
									 	"com.sun.java.swing.plaf.gtk.GTKLookAndFeel",
										"com.sun.java.swing.plaf.motif.MotifLookAndFeel",
										"com.sun.java.swing.plaf.mac.MacLookAndFeel"
										
	};
	
	private static HTKMainWindow htkMainWindow = null;
	
	private javax.swing.JPanel jContentPane = null;

	private JMenuBar jJMenuBar = null;
	private JTabbedPane jTabbedPane = null;
	private JMenu jMenu = null;
	private JMenu jMenu1 = null;
	private JMenuItem jMenuItem = null;
	private ViewerTabPanel viewerPanel = null;
	private QueryTabPanel queryTabPanel = null;
	private SettingTabPanel setting = null;
	private ContentTabWindow contentTabWindow = null;
	private JMenuItem jMenuItem1 = null;
	private JMenuItem jMenuItem2 = null;
	/**
	 * This is the default constructor
	 */
	public MainWindow() {
		super();
		initialize();
	}
	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setJMenuBar(getJJMenuBar());
		this.setSize(WINDOW_WIDTH,WINDOW_HEIGHT);
		this.setContentPane(getJContentPane());
		this.setTitle("Hiromicam");
		this.setResizable(false);
		
		// setting Look and Feel
		try {
			UIManager.setLookAndFeel(lookAndFeelStr[0]);
			SwingUtilities.updateComponentTreeUI(this);
		} catch (ClassNotFoundException e1) {
			
			e1.printStackTrace();
		} catch (InstantiationException e1) {
			
			e1.printStackTrace();
		} catch (IllegalAccessException e1) {
			
			e1.printStackTrace();
		} catch (UnsupportedLookAndFeelException e1) {
			
			e1.printStackTrace();
		}

		this.addWindowListener(
				new WindowAdapter() {
					public void windowClosing(WindowEvent e) {
						System.exit(0);
					}
				}
			);
	}
	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private javax.swing.JPanel getJContentPane() {
		if(jContentPane == null) {
			jContentPane = new javax.swing.JPanel();
			jContentPane.setLayout(new java.awt.BorderLayout());
			jContentPane.add(getJTabbedPane(), java.awt.BorderLayout.CENTER);
		}
		return jContentPane;
	}
	/**
	 * This method initializes jJMenuBar	
	 * 	
	 * @return javax.swing.JMenuBar	
	 */    
	private JMenuBar getJJMenuBar() {
		if (jJMenuBar == null) {
			jJMenuBar = new JMenuBar();
			jJMenuBar.add(getJMenu());
			jJMenuBar.add(getJMenu1());
		}
		return jJMenuBar;
	}
	/**
	 * This method initializes jTabbedPane	
	 * 	
	 * @return javax.swing.JTabbedPane	
	 */    
	private JTabbedPane getJTabbedPane() {
		if (jTabbedPane == null) {
			jTabbedPane = new JTabbedPane();
			jTabbedPane.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
			jTabbedPane.addTab("Viewer", null, getViewerPanel(), null);
			jTabbedPane.addTab("Query", null, getQueryTabPanel(), null);
			jTabbedPane.addTab("Content", null, getContentTabWindow(), null);
			jTabbedPane.addTab("Setting", null, getSetting(), null);
		}
		return jTabbedPane;
	}
	/**
	 * This method initializes jMenu	
	 * 	
	 * @return javax.swing.JMenu	
	 */    
	private JMenu getJMenu() {
		if (jMenu == null) {
			jMenu = new JMenu();
			jMenu.setText("File");
			jMenu.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
			jMenu.add(getJMenuItem2());
			jMenu.add(getJMenuItem());
		}
		return jMenu;
	}
	/**
	 * This method initializes jMenu1	
	 * 	
	 * @return javax.swing.JMenu	
	 */    
	private JMenu getJMenu1() {
		if (jMenu1 == null) {
			jMenu1 = new JMenu();
			jMenu1.setText("Help");
			jMenu1.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
			jMenu1.add(getJMenuItem1());
		}
		return jMenu1;
	}
	/**
	 * This method initializes jMenuItem	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */    
	private JMenuItem getJMenuItem() {
		if (jMenuItem == null) {
			jMenuItem = new JMenuItem();
			jMenuItem.setName("exit");
			jMenuItem.setText("Exit");
			jMenuItem.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
			jMenuItem.addActionListener(new java.awt.event.ActionListener() { 
				public void actionPerformed(java.awt.event.ActionEvent e) {
					// exit this sofoware.
					System.exit(0);
				}
			});
		}
		return jMenuItem;
	}
	/**
	 * This method initializes viewerPanel	
	 * 	
	 * @return jnet.application.gui.ViewerPanel	
	 */    
	private ViewerTabPanel getViewerPanel() {
		if (viewerPanel == null) {
			viewerPanel = new ViewerTabPanel();
			viewerPanel.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 10));
		}
		return viewerPanel;
	}
	/**
	 * This method initializes queryTabPanel	
	 * 	
	 * @return jnet.application.gui.QueryTabPanel	
	 */    
	private QueryTabPanel getQueryTabPanel() {
		if (queryTabPanel == null) {
			queryTabPanel = new QueryTabPanel();
		}
		return queryTabPanel;
	}
	/**
	 * This method initializes setting	
	 * 	
	 * @return jnet.application.gui.Setting	
	 */    
	private SettingTabPanel getSetting() {
		if (setting == null) {
			setting = new SettingTabPanel();
		}
		return setting;
	}
	/**
	 * This method initializes contentTabWindow	
	 * 	
	 * @return jnet.application.gui.ContentTabWindow	
	 */    
	private ContentTabWindow getContentTabWindow() {
		if (contentTabWindow == null) {
			contentTabWindow = new ContentTabWindow();
		}
		return contentTabWindow;
	}
	/**
	 * This method initializes jMenuItem1	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */    
	private JMenuItem getJMenuItem1() {
		if (jMenuItem1 == null) {
			jMenuItem1 = new JMenuItem();
			jMenuItem1.setText("About Hiromicam platform");
			jMenuItem1.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
		}
		return jMenuItem1;
	}
	/**
	 * This method initializes jMenuItem2	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */    
	private JMenuItem getJMenuItem2() {
		if (jMenuItem2 == null) {
			jMenuItem2 = new JMenuItem();
			jMenuItem2.setText("Hiromicam Tool Kit");
			jMenuItem2.addActionListener(new java.awt.event.ActionListener() { 
				public void actionPerformed(java.awt.event.ActionEvent e) {    
					if (htkMainWindow == null) {
						htkMainWindow = new HTKMainWindow();
					}
					htkMainWindow.setLocation(WINDOW_WIDTH, 0);
					htkMainWindow.setVisible(true);
				}
			});
		}
		return jMenuItem2;
	}
	/**
	 * @return Returns the htkMainWindow.
	 */
	public static HTKMainWindow getHtkMainWindow() {
		return htkMainWindow;
	}
 }
