/*
 * Created on 2004/06/22
 */
package jnet.gps.geo;

/**
 * This class calculate a distance between twe point.
 * using hyubeni method
 * D=sqrt((M*dP)*(M*dP)+(N*cos(P)*dR)*(N*cos(P)*dR)) 
 * D:  distance between 2 point(m)
 * P:  average latitude of 2 point (Radians)
 * dP: distance latitude of 2 point(Radians)
 * dR: distance longitude of 2 point(Radians)
 * M:  Meridian line curvature radius
 * M=6334834/sqrt((1-0.006674*sin(P)*sin(P))^3)
 * N:  bouyuu line curvature radius
 * N=6377397/sqrt(1-0.006674*sin(P)*sin(P)) 
 * 
 * @author Kazuya Sakai
 * @version 1.00
 * @since jdk 1.4.2
 */
public class DistanceCalculater {
	
	/**
	 * This method calculate distance of X position between twe point.
	 * 
	 * @param myLatitude my Latitude Value
	 * @param myLongitude my Longitude Value
	 * @param incomLatitude target Latitude Value
	 * @param incomLongitude target Longitude Value
	 * @return x position distance between you and incoming terminal
	 */
	public static int getHorizontalCordinate( String myLatitude,
												String myLongitude,
												String incomLatitude,
												String incomLongitude) {
		
		double aveLatitude = (Double.parseDouble(myLatitude)
					+  Double.parseDouble(incomLatitude)) / 200;	// average latitude of 2 point
		
		double differenceLongitude = (Double.parseDouble(myLongitude)
					- Double.parseDouble(incomLongitude)) / 100;	// distance longitude of 2 point
		double differenceLatitude = (Double.parseDouble(myLatitude)
					- Double.parseDouble(incomLatitude)) / 100;		// distance latitude of 2 point
		
		double bouyuu = 6377397
				/ Math.sqrt(1 - 0.006674 * Math.sin(Math.toRadians(aveLatitude))
						* Math.sin(Math.toRadians(aveLatitude)));	// bouyuu line curvature radius
		
		return (int)(bouyuu * Math.cos(Math.toRadians(aveLatitude)) * Math.toRadians(differenceLongitude));
	}
	/**
	 * This method calculate distance of Y position between twe point.
	 * 
	 * @param myLatitude my Latitude Value
	 * @param myLongitude my Longitude Value
	 * @param incomLatitude target Latitude Value
	 * @param incomLongitude target Longitude Value
	 * @return y position distance between you and incoming terminal
	 */
	public static int getVerticalCordinate( String myLatitude,
											  String myLongitude,
											  String incomLatitude,
											  String incomLongitude) {
		double aveLatitude = (Double.parseDouble(myLatitude)
					+ Double.parseDouble(incomLatitude)) / 200;			// average latitude of 2 point

		double differenceLongitude = (Double.parseDouble(myLongitude)
					- Double.parseDouble(incomLongitude)) / 100;		// distance longitude of 2 point
		double differenceLatitude =  (Double.parseDouble(myLatitude)
					- Double.parseDouble(incomLatitude)) / 100;			// distance latitude of 2 point

		double meridian = 6334834
				/ Math.sqrt(Math.pow(1-0.006674 * Math.sin(Math.toRadians(aveLatitude))
						* Math.sin(Math.toRadians(aveLatitude)), 3.0));	// Meridian line curvature radius
		
		return (int)(meridian * Math.toRadians(differenceLatitude));
	}
	/**
	 * This method calculate distance between twe point.
	 * 
	 * @param myLatitude my Latitude Value
	 * @param myLongitude my Longitude Value
	 * @param incomLatitude target Latitude Value
	 * @param incomLongitude target Longitude Value
	 * @return distance between you and incoming terminal
	 */
	public static int getDistance( String myLatitude,
									 String myLongitude,
									 String incomLatitude,
									 String incomLongitude) {
		double aveLatitude = (Double.parseDouble(myLatitude)
					+ Double.parseDouble(incomLatitude)) / 200;			// average latitude of 2 point
		
		double differenceLongitude = (Double.parseDouble(myLongitude)
					- Double.parseDouble(incomLongitude)) / 100;		// distance longitude of 2 point
		double differenceLatitude =  (Double.parseDouble(myLatitude)
					- Double.parseDouble(incomLatitude)) / 100;			// distance latitude of 2 point
		
		double meridian = 6334834
				/ Math.sqrt(Math.pow(1-0.006674 * Math.sin(Math.toRadians(aveLatitude))
						* Math.sin(Math.toRadians(aveLatitude)), 3.0));	// Meridian line curvature radius
		double bouyuu = 6377397
				/ Math.sqrt(1 - 0.006674 * Math.sin(Math.toRadians(aveLatitude))
						* Math.sin(Math.toRadians(aveLatitude)));		// bouyuu line curvature radius
		
		return Math.abs((int)(Math.sqrt((meridian * Math.toRadians(differenceLatitude)) 
					* (meridian * Math.toRadians(differenceLatitude))
					+ (bouyuu * Math.cos(Math.toRadians(aveLatitude))
							* Math.toRadians(differenceLongitude))
							* (bouyuu * Math.cos(Math.toRadians(aveLatitude))
									* Math.toRadians(differenceLongitude)))));
	}
}
