/*
 * Created on 2005/01/21
 *
 */
package jnet.hiromicam.buff;

import java.util.ArrayList;

import jnet.hiromicam.msg.FirstLevelInfo;

/**
 * This class for logging incoming First-Level Information.
 * As for this class, only one exists in this program.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class FirstLevelInfoBuff {
	/**
	 * a max size of target list.
	 */
	private final int TARGET_SIZE = 255;
	
	/**
	 * This is only instance of HighLevelInfoBuff.
	 */
	private static FirstLevelInfoBuff logger = new FirstLevelInfoBuff();
	
	/**
	 * This is list of terminals sent message.
	 */
	private ArrayList terminalLists = new ArrayList();
	
	/**
	 * nobady create instance from constractor.
	 *
	 */
	private FirstLevelInfoBuff() {
		
	}
	
	/**
	 * This method reuturn instance of this class.
	 * 
	 * @return instance of this class.
	 */
	public static FirstLevelInfoBuff getInstance() {
		return logger;
	}
	
	/**
	 * This method is for adding First-Level Information to log.
	 * 
	 * @param ipAddr IP Address of target terminal
	 * @param hostName Hostname of target terminal
	 * @param msg Message to add log.
	 * @return true : success adding message, false : other
	 */
	public boolean addFirstLevelInfo(String ipAddr, String hostName, FirstLevelInfo msg) {
		
		for (int i = 0; i < terminalLists.size(); i++) {
			Terminal terminal = (Terminal)terminalLists.get(i);
			if (ipAddr.equals(terminal.getIpAddr())) {
				// adding to log.
				if (terminal.addFirstLevelInfo(msg)) {
					return true;
				} else {
					// when same information will be added, it return false.
					return false;
				}
			}
		}
		
		// if terminal list is full, this system don't add new terminal.
		if (terminalLists.size() >= TARGET_SIZE) {
			return false;
		}
		
		// when terminal send message isn't in log, new terminal object created and added to list.
		Terminal newTerminal = new Terminal(ipAddr, hostName);
		newTerminal.addFirstLevelInfo(msg);
		if (terminalLists.add(newTerminal)) {
			return true;
		} else {
			return false;
		}
	}
	
	/**
	 * This method reflesh Log.
	 * 
	 * @param currentTime current time.
	 * @return success refleshing Log or not.
	 */
	public boolean refleshLog(String currentTime) {
		
		for (int i = 0; i < terminalLists.size(); i++) {
			Terminal t = (Terminal)terminalLists.get(i);
			if (Integer.parseInt(currentTime)
				- Integer.parseInt(
						((FirstLevelInfo)t.getFirstLevelInfoLists().get(t.getFirstLevelInfoLists().size() - 1)).getTime())
						> 1){
				terminalLists.remove(i);
			}
		}
		
		return true;
	}
	
	// This method override document of super class.
	public String toString() {
		String str = "";
		
		for (int i = 0; i < terminalLists.size(); i++) {
			Terminal t = (Terminal)terminalLists.get(i);
			str += t.toString();
		}
		
		return str;
	}
	
	/**
	 * This returns Terminal List.
	 * 
	 * @return Returns the terminalLists.
	 */
	public ArrayList getTerminalLists() {
		return terminalLists;
	}
}
