/*
 * Created on 2005/01/21
 *
 */
package jnet.hiromicam.buff;

import java.util.ArrayList;

import jnet.hiromicam.msg.FirstLevelInfo;

/**
 * This class expresses a termial that send Message.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class Terminal {
	
	/**
	 * This is log size.
	 * for example, when LOG_SIZE = 5, this system save 5 First-Level Information
	 * ; 1 sec befor, 2 sec ... , 5 sec befor.
	 */
	protected int buffSize = 10;
	
	/**
	 * IP Address of this terminal.
	 */
	private String ipAddr;
	
	/**
	 * HostName of this terminal.
	 */
	private String hostName;
	
	/**
	 * History of First-Level Information of this teminal.
	 */
	private ArrayList firstLevelInfoLists = new ArrayList();
	
	/**
	 * This is a default constractor.
	 * 
	 * @param ipAddr IP Address
	 * @param hostName HostName
	 */
	public Terminal(String ipAddr, String hostName) {
		this.ipAddr = ipAddr;
		this.hostName = hostName;
	}
	
	/**
	 * This method add First-Level Information to history of this terminal information.
	 * 
	 * @param msg First-Level Information for adding to this history.
	 * @return true : success adding message, false : other
	 */
	public boolean addFirstLevelInfo(FirstLevelInfo msg) {
		
		for (int i = 0; i < firstLevelInfoLists.size(); i++) {
			// checking same information is in list or not.
			// if the message will added is in list, the massage is not added.
			FirstLevelInfo oldMsg = (FirstLevelInfo)firstLevelInfoLists.get(i);
			if (msg.getTime().equals(oldMsg.getTime())) {
				return false;
			}
		}
		
		// if the message isn't in list, it is added to list.
		firstLevelInfoLists.add(msg);
			
		// if buffere size is over BUFF_SIZE,
		// this system remove the oldest message.
		if (firstLevelInfoLists.size() > buffSize) {
			firstLevelInfoLists.remove(0);
		}
		
		return true;
	}
	
	/**
	 * @return Returns the highLevelInfoLists.
	 */
	public ArrayList getFirstLevelInfoLists() {
		return firstLevelInfoLists;
	}
	
	/**
	 * @return Returns the hostName.
	 */
	public String getHostName() {
		return hostName;
	}
	
	/**
	 * @return Returns the ipAddr.
	 */
	public String getIpAddr() {
		return ipAddr;
	}
	
	// This method override document of supper class
	public String toString() {
		String str = "IP Address = " + ipAddr + "\n"
					 + "HostName = " + hostName + "\n";
		
		for (int i = 0; i < firstLevelInfoLists.size(); i++) {
			str += ((FirstLevelInfo)firstLevelInfoLists.get(i)).getMsg() + "\n";
		}
		return str + "\n";
	}
}
