/*
 * Created on 2004/06/20
 */
package jnet.hiromicam.comm;

import javax.comm.*;
import java.util.*;
import java.io.*;

import jnet.hiromicam.core.FirstLevelInfoProcessor;
import jnet.hiromicam.properity.SystemProperty;
import jnet.hiromicam.util.file.GpsInfoLogger;


/**
 * This class for get GPS infomation in GGA format.
 * GPS infomation is received at per second 1 time of a rate.
 * 
 * @author Kazuya Sakai
 * @version 1.00
 * @since jdk 1.4.2
 */
public class SerialPortAddapter
	extends SerialPortHandler
	implements Runnable, SerialPortEventListener {

		protected BufferedReader comReader;
				
		/**
		 * 
		 * @param portName port name
		 */
		public SerialPortAddapter(String portName){
			super(portName);

			try {
				// Registration of the listeners for receiving SerialPortEvent
				port.addEventListener(this);
			} catch(TooManyListenersException ex){
				ex.printStackTrace();
			}

			// A Data Available event is received.
			port.notifyOnDataAvailable(true);

			try {
				// create Reader for RS-232C inputting.
				comReader = new BufferedReader(
						 new InputStreamReader(port.getInputStream()));
			} catch (IOException ex){
				ex.printStackTrace();
				System.exit(1);
			}
		}
		
		/**
		 * Event processing routine
		 */
		public void serialEvent(SerialPortEvent event) {
			switch(event.getEventType()) {
			  case SerialPortEvent.BI:
			  case SerialPortEvent.OE:
			  case SerialPortEvent.FE:
			  case SerialPortEvent.PE:
			  case SerialPortEvent.CD:
			  case SerialPortEvent.CTS:
			  case SerialPortEvent.DSR:
			  case SerialPortEvent.RI:
			  case SerialPortEvent.OUTPUT_BUFFER_EMPTY:
				// No events other than Data Available process.
				break;
			  case SerialPortEvent.DATA_AVAILABLE:
				// processing of Data Available.
				String buffer = null;
				try {
					while (comReader.ready()) {
						// read data from sirial port.
						buffer = comReader.readLine();
						// if you get infomation of GGA format, create GpsInfo. 
						if(buffer.startsWith("$GPGGA")){
							try {
								// processing GGA data
								FirstLevelInfoProcessor.processGpsInfo(buffer);
								System.out.println(buffer);
								// log GPS information
								if (SystemProperty.getInstance().isGpsInfoLogger()) {
									GpsInfoLogger.getInstance().addGpsInfo(buffer);
								}
								
							} catch (Exception e1) {
								e1.printStackTrace();
							}
						}
					}
				} catch (IOException e){}
				break;
			}
		}

		public void start(){
			new Thread(this).start();
		}

		public void run(){
		}
}
