/*
 * Created on 2004/06/20
 */
package jnet.hiromicam.comm;

import javax.comm.*;

/**
 * This class for controling sirial port.
 * 
 * @author Kazuya Sakai
 * @version 1.00
 * @since jdk 1.4.2
 */
public class SerialPortHandler {
	
	private static final int TIME_OUT = 5000;			// timeout (ms)
	
	protected SerialPort port;
	
	/**
	 * create port handler.
	 * 
	 * @param portName PortNumber for using Hirommy.
	 */
	public SerialPortHandler(String portName) {
		CommPortIdentifier portID = null;
		try{	// get CommPortIdentifier.
			portID = CommPortIdentifier.getPortIdentifier(portName);
		}catch(NoSuchPortException ex) {
			ex.printStackTrace();
			System.exit(1);
		}

		try {	// open port.
			port = (SerialPort)portID.open("GPSReceiver", TIME_OUT);
		} catch(PortInUseException ex) {	// When it passes over a timeout.
			System.out.println("Error : A setup of a port is wrong.");
			ex.printStackTrace();
		}

		try {	// A setup of communication conditions
			port.setSerialPortParams(4800, 						// communication speed 4800 baud
									 SerialPort.DATABITS_8, 	// databit 8bit
									 SerialPort.STOPBITS_1, 	// stopbit 1bit
									 SerialPort.PARITY_NONE); 	// Parity none
			// A set up flow control
			// Here, a hard flow control (RTS/CTS) is used.
			port.setFlowControlMode(SerialPort.FLOWCONTROL_RTSCTS_IN
									| SerialPort.FLOWCONTROL_RTSCTS_OUT);
		} catch (UnsupportedCommOperationException ex){
			ex.printStackTrace();
		}
	}
	
	/**
	 * close port.
	 */
	public void close() {
		port.close();
	}
}


