/*
 * Created on 2005/01/20
 *
 */
package jnet.hiromicam.core;

import jnet.gps.process.SimpleDirectionCalculationMethod;
import jnet.gps.process.SimpleSpeedCalculationMethod;
import jnet.hiromicam.algorithm.event.ActionAnalyzer;
import jnet.hiromicam.algorithm.event.SimpleSpeedActionAnalyzer;
import jnet.hiromicam.buff.MyTerminal;
import jnet.hiromicam.msg.FirstLevelInfo;
import jnet.hiromicam.msg.Msg;
import jnet.hiromicam.msg.factory.FirstLevelInfoFactory;

/**
 * This class is for processing GPS information.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class FirstLevelInfoProcessor {
	/**
	 * This value is factory class.
	 * You can chose calculation method of speed and direction.
	 */
	private static FirstLevelInfoFactory factory =
			new FirstLevelInfoFactory(new SimpleSpeedCalculationMethod(),
									  new SimpleDirectionCalculationMethod());
	
	/**
	 * This value is class for analyzing for First-Level Information.
	 */
	private static ActionAnalyzer analyzer =
			new SimpleSpeedActionAnalyzer();
	
	/**
	 * This method process GPS information.
	 * 
	 * @param ggaData GGA Data from satellite
	 * @return First-Level Information
	 */
	public static Msg processGpsInfo(String ggaData) {
		// creating First-Level Information.
		FirstLevelInfo msg = factory.createFirstLevelInfo(ggaData);
		
		// analyze
		if (analyzer.isAbnormalAction(msg, MyTerminal.getInstance().getFirstLevelInfoLists())) {
			msg.setState(Msg.ABNORMAL);
		} else {
			msg.setState(Msg.NORMAL);
		}
		
		// sendding First-Level Information message
		MsgSender.sendMsg(msg);
		
		// logging
		MyTerminal.getInstance().addFirstLevelInfo(msg);
		
		return msg;
	}
}
