/*
 * Created on 2004/08/07
 *
 */
package jnet.hiromicam.core;

import java.io.IOException;
import java.net.*;

import jnet.hiromicam.msg.Msg;
import jnet.hiromicam.properity.SystemProperty;


/**
 * This class send Message.
 * UDP is used for transmission of a packet in Message.
 * 
 * @author Kazuya Sakai
 * @version 2.0
 * @since jdk 1.4.2
 */
public class MsgSender {
	
	/**
	 * This method for sending Message.
	 * 
	 * @param msg Msg object to send.
	 */
	public static void sendMsg(Msg msg) {
		try {
			// get destintion IP Address.
			// Hiromicam broadcast a packet, so A broadcast address is set as the target address.
			InetAddress destAddr = InetAddress.getByName("255.255.255.255");
			
			//  UDP socket for sending message
			DatagramSocket sock = new DatagramSocket();
			
			// transfor message to byte.
			byte[] bytesToSend = msg.getMsg().getBytes();
			
			
			DatagramPacket packet = new DatagramPacket( bytesToSend,
														bytesToSend.length,
														destAddr,
														SystemProperty.PORT);	
			
			// send Hiromicam Packet with UDPsocket.
			sock.send(packet);				// send latest my Hiromicam Packet.
			
		} catch (UnknownHostException e) {
			System.out.println("Error : Acquisition of a destination address goes wrong.");
			e.printStackTrace();
		} catch (SocketException e) {
			System.out.println("Error : An error occurs in UDP.");
			e.printStackTrace();
		} catch (IOException e) {
			System.out.println("Error : An error occurs IOException.");
			e.printStackTrace();
		}		
	}
}
