/*
 * Created on 2005/01/20
 *
 */
package jnet.hiromicam.msg;

import jnet.hiromicam.properity.SystemProperty;

/**
 * This is class for First-Level Information. 
 * This type of information is continuously exchanged per 1 second.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class FirstLevelInfo extends MsgImpl {
	
	/**
	 * This represents tag of the time.
	 */
	public static final String TIME_TAG = "Time";
	
	/**
	 * This represents tag of the latitude.
	 */
	public static final String LATITUDE_TAG = "Latitude";
	
	/**
	 * This represents tag of the latitude.
	 */
	public static final String LONGITUDE_TAG = "Longitude";
	
	/**
	 * This represents tag of the Measurement.
	 */
	public static final String MEASUAMENT_TAG = "Measurement";
	
	/**
	 * This represents tag of the satellite.
	 */
	public static final String SATELLITE_TAG = "Satellite";
	
	/**
	 * This represents tag of the altitude.
	 */
	public static final String ALTITUDE_TAG = "Altitude";
	
	/**
	 * This represents tag of the state.
	 */
	public static final String SPEED_TAG = "Speed";
	
	/**
	 * This represents tag of the direction.
	 */
	public static final String DIRECTION_TAG = "Direciton";
	
	/**
	 * This represents tag of the speed.
	 */
	public static final String STATE_TAG = "State";
	
	/**
	 * IP Address of this terminal.
	 */
	private String ipAddr;
	
	/**
	 * HostName of this terminal.
	 */
	private String hostName;
	
	/**
	 * time time when this GPS infomation is getted from satellite.
	 */
	private String time;
	
	/**
	 * latitude.
	 */
	private String latitude;

	/**
	 * longitude.
	 */
	private String longitude;
	
	/**
	 * Position state.
	 */
	private String measurement;
	
	/**
	 * the number of Satellite.
	 */
	private String satellite;
	
	/**
	 * Altitude
	 */
	private String altitude;
	
	/**
	 * speed
	 */
	private String speed;
	
	/**
	 * speed
	 */
	private String direction;
	
	/**
	 * state of terminal.
	 * true:normal, false:abnormal
	 */
	private String state;
	
	/**
	 * This is a constractor for generating new content.
	 * 
	 * @param time the time when this GPS infomation is getted from satellite.
	 * @param latitude the latitude.
	 * @param longitude the longitude.
	 * @param measurement the position state.
	 * @param satellite the number of satelite.
	 * @param altitude the altitude.
	 * @param speed the speed of this terminal.
	 * @param direction the direciton of this terminal go for.
	 */
	public FirstLevelInfo (String time,
						   String latitude,
						   String longitude,
						   String measurement,
						   String satellite,
						   String altitude,
						   String speed,
						   String direction) {
		this.msgType = Msg.FIRSTLEVEL_INFO;
		this.ipAddr = SystemProperty.getInstance().getAddr();
		this.hostName = SystemProperty.getInstance().getHostName();
		this.time = time;
		this.latitude = latitude;
		this.longitude = longitude;
		this.measurement = measurement;
		this.satellite = satellite;
		this.altitude = altitude;
		this.speed = speed;
		this.direction = direction;
	}
	
	/**
	 * This is a constractor for generating from received Message.
	 * 
	 * @param time the time when this GPS infomation is getted from satellite.
	 * @param latitude the latitude.
	 * @param longitude the longitude.
	 * @param measurement the position state.
	 * @param satellite the number of satelite.
	 * @param altitude the altitude.
	 * @param speed the speed of this terminal.
	 * @param direction the direciton of this terminal go for.
	 * @param state the state of this termnal.
	 * 
	 */
	public FirstLevelInfo (String time,
						    String latitude,
							String longitude,
							String measurement,
							String satellite,
							String altitude,
							String speed,
							String direction,
							String state) {
		this.msgType = Msg.FIRSTLEVEL_INFO;
		this.ipAddr = SystemProperty.getInstance().getAddr();
		this.hostName = SystemProperty.getInstance().getHostName();
		this.time = time;
		this.latitude = latitude;
		this.longitude = longitude;
		this.measurement = measurement;
		this.satellite = satellite;
		this.altitude = altitude;
		this.speed = speed;
		this.direction = direction;
		this.state = state;
	}
	
	/**
	 * @return Returns the altitude.
	 */
	public String getAltitude() {
		return altitude;
	}
	
	/**
	 * @return Returns the direction.
	 */
	public String getDirection() {
		return direction;
	}
	
	/**
	 * @return Returns the hostName.
	 */
	public String getHostName() {
		return hostName;
	}
	
	/**
	 * @return Returns the ipAddr.
	 */
	public String getIpAddr() {
		return ipAddr;
	}
	
	/**
	 * @return Returns the latitude.
	 */
	public String getLatitude() {
		return latitude;
	}
	
	/**
	 * @return Returns the longitude.
	 */
	public String getLongitude() {
		return longitude;
	}
	
	/**
	 * @return Returns the measurement.
	 */
	public String getMeasurement() {
		return measurement;
	}
	
	/**
	 * @return Returns the satellite.
	 */
	public String getSatellite() {
		return satellite;
	}
	
	/**
	 * @return Returns the state.
	 */
	public String getState() {
		return state;
	}
	
	/**
	 * @return Returns the speed.
	 */
	public String getSpeed() {
		return speed;
	}
	
	/**
	 * @param state The state to set.
	 */
	public void setState(String state) {
		this.state = state;
	}
	
	/**
	 * @return Returns the time.
	 */
	public String getTime() {
		return time;
	}
	
	/**
	 * This method is for returning XML format of this message.
	 * 
	 * @return XML format of this class
	 */
	public String getMsg() {
		return XML_HEADDER + "\n"
				+ "<" + FIRST_LEVEL_INFO_TAG + ">" + "\n"
				+ "\t<" + IP_ADDRESS_TAG + ">" + ipAddr + "</" + IP_ADDRESS_TAG + ">\n"
				+ "\t<" + HOSTNAME_TAG + ">" + hostName + "</" + HOSTNAME_TAG + ">\n"
				+ "\t<" + TIME_TAG + ">" + time + "</" + TIME_TAG +">\n"
				+ "\t<" + LATITUDE_TAG + ">" + latitude + "</" + LATITUDE_TAG + ">\n"
				+ "\t<" + LONGITUDE_TAG  + ">"+ longitude + "</" + LONGITUDE_TAG + ">\n"
				+ "\t<" + MEASUAMENT_TAG + ">" + measurement + "</" + MEASUAMENT_TAG + ">\n"
				+ "\t<" + SATELLITE_TAG + ">" + satellite + "</" + SATELLITE_TAG + ">\n"
				+ "\t<" + ALTITUDE_TAG + ">" + altitude + "</" + ALTITUDE_TAG + ">\n"
				+ "\t<" + SPEED_TAG + ">" + speed + "</" + SPEED_TAG + ">\n"
				+ "\t<" + DIRECTION_TAG + ">" + direction + "</" + DIRECTION_TAG + ">\n"
				+ "\t<" + STATE_TAG + ">" + state + "</" + STATE_TAG + ">\n"
				+ "</" + FIRST_LEVEL_INFO_TAG + ">";
	}
}
