/*
 * Created on 2005/01/21
 *
 */
package jnet.hiromicam.msg.pase;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.FactoryConfigurationError;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.xml.sax.SAXException;

import jnet.hiromicam.msg.FirstLevelInfo;
import jnet.hiromicam.msg.Msg;

/**
 * This class pase XML data of First-Level Information.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class FirstLevelInfoPaser implements MsgPase {
	
	/* (non-Javadoc)
	 * @see jnet.hiromicam.msg.pase.MsgPase#paseXML()
	 */
	public Msg paseXML(String str) {
		
		String time = null;			// time
		String latitude = null;		// latitude
		String longitude = null;	// longitude
		String measurement = null;	// measurement
		String satellite = null;	// satellite
		String altitude = null;		// altitude
		String speed = null;		// speed
		String direction = null;	// direction
		String state = null;		// state
		
		try {
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = factory.newDocumentBuilder();
			
			Document doc = builder.parse(new ByteArrayInputStream(str.getBytes()));
			
			// getting root element : First-Level Information
			Element root = doc.getDocumentElement();
			
			NodeList children = root.getChildNodes();
			
			for (int i = 0; i < children.getLength(); i++) {
				Node element = children.item(i);
				if (element instanceof Element) {
					Element childElement = (Element)element;
					Text textNode = (Text)childElement.getFirstChild();
					String value = textNode.getData().trim();
					
					if (childElement.getTagName().equals(FirstLevelInfo.TIME_TAG)) {
						time = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.LATITUDE_TAG)) {
						latitude = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.LONGITUDE_TAG)) {
						longitude = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.MEASUAMENT_TAG)) {
						measurement = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.SATELLITE_TAG)) {
						satellite = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.ALTITUDE_TAG)) {
						altitude = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.SPEED_TAG)) {
						speed = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.DIRECTION_TAG)){
						direction = value;
					} else if (childElement.getTagName().equals(FirstLevelInfo.STATE_TAG)) {
						state = value;
					}
				}
				
			}
			

			
		} catch (FactoryConfigurationError e) {
			System.out.println("Error : FactoryConfigurationError");
			e.printStackTrace();
		} catch (ParserConfigurationException e) {
			System.out.println("Error : ParserConfigurationException");
			e.printStackTrace();
		} catch (IOException e) {
			System.out.println("Error : IOException");
			e.printStackTrace();
		} catch (SAXException e) {
			System.out.println("Error : SAXException");
			e.printStackTrace();
		}
		
		return new FirstLevelInfo(time,
								   latitude,
								   longitude,
								   measurement,
								   satellite,
								   altitude,
								   speed,
								   direction,
								   state);
	}
}
