/*
 * Created on 2005/01/30
 *
 */
package jnet.hiromicam.msg.pase;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.FactoryConfigurationError;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.xml.sax.SAXException;

import jnet.hiromicam.msg.AbstractSecondLevelInfo;
import jnet.hiromicam.msg.EmergencyInfo;
import jnet.hiromicam.msg.Msg;

/**
 * This class pase XML data of Second-Level Information.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class SecondLevelInfoPaser implements MsgPase {

	/* (non-Javadoc)
	 * @see jnet.hiromicam.msg.pase.MsgPase#paseXML(java.lang.String)
	 */
	public Msg paseXML(String str) {
		try {
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = factory.newDocumentBuilder();
			
			Document doc = builder.parse(new ByteArrayInputStream(str.getBytes()));
			
			// getting root element : Second-Level Information
			Element root = doc.getDocumentElement();
			
			NodeList children = root.getChildNodes();
			
			for (int i = 0; i < children.getLength(); i++) {
				Node element = children.item(i);
				if (element instanceof Element) {
					Element childElement = (Element)element;
					Text textNode = (Text)childElement.getFirstChild();
					String value = textNode.getData().trim();
					
					if (childElement.getTagName().equals(AbstractSecondLevelInfo.CONTENT_TYPE_TAG)) {
						// search content type.
						if (value.equals(EmergencyInfo.EMERGENCY_ATTRIBUTE)) {
							// pase Emergency Information.
							return paseEmergencyInfo(str);
						}
					}
				}
				
			}
		} catch (FactoryConfigurationError e) {
			e.printStackTrace();
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
		} catch (SAXException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return null;
	}
	
	/**
	 * This method pases XML document of EmergencyInfo.
	 * 
	 * @param str XML document
	 * @return an object of the EmegencyInfo.
	 */
	private Msg paseEmergencyInfo(String str) {
		
		String contentID = null;						// content ID
		String contentType = null;						// content type
		String priority = null;							// priority
		String generatedTime = null;					// the time when this content was generated.
		String generator = null;						// the generator of this content
		ArrayList sourceContentID = new ArrayList();	// the source content ID.
		
		String accidentTime = null;						// the time when an accident occured.
		String accidentLatitude = null;					// the latitude where an accident occured.
		String accidentLongitude = null;				// the longitude where an accident occured.
		String accidentType = null;						// the type of the accident.
		String detailInfo = null;						// the information of this emergency situation.
		
		try {
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = factory.newDocumentBuilder();
			
			Document doc = builder.parse(new ByteArrayInputStream(str.getBytes()));
			
			// getting root element : Second-Level Information
			Element root = doc.getDocumentElement();
			
			NodeList children = root.getChildNodes();
			
			for (int i = 0; i < children.getLength(); i++) {
				Node element = children.item(i);
				if (element instanceof Element) {
					Element childElement = (Element)element;
					Text textNode = (Text)childElement.getFirstChild();
					String value = textNode.getData().trim();
						
					if (childElement.getTagName().equals(AbstractSecondLevelInfo.CONTENT_ID_TAG)) {
						contentID = value;
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.GENERATED_TIME_TAG)) {
						generatedTime = value;
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.GENERATOR_TAG)) {
						generator = value;
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.PRIORITY_TAG)) {
						priority = value;
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.CONTENT_TYPE_TAG)) {
						contentType = value;
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.SOURCE_CONTENT_ID_TAG)) {
						sourceContentID.add(value);
					} else if (childElement.getTagName().equals(AbstractSecondLevelInfo.CONTENT_TAG)) {
						// pase <Content>
						NodeList grandChildren = element.getChildNodes();
						
						for (int j = 0; j < grandChildren.getLength(); j++) {
							Node contentElement = grandChildren.item(j);
							if (contentElement instanceof Element) {
								Element grandChildElement = (Element)contentElement;
								Text grandTextNode = (Text)grandChildElement.getFirstChild();
								String contentValue = grandTextNode.getData().trim();
								
								if (grandChildElement.getTagName().equals(EmergencyInfo.ACCIDENT_TIME_TAG)) {
									accidentTime = contentValue;
								} else if (grandChildElement.getTagName().equals(EmergencyInfo.ACCIDENT_LATITUDE_TAG)) {
									accidentLatitude = contentValue;
								} else if (grandChildElement.getTagName().equals(EmergencyInfo.ACCIDENT_LONGITUDE_TAG)) {
									accidentLongitude = contentValue;
								} else if (grandChildElement.getTagName().equals(EmergencyInfo.ACCIDENT_TYPE_TAG_TAG)) {
									accidentType = contentValue;
								} else if (grandChildElement.getTagName().equals(EmergencyInfo.DETAIL_INFO_TAG)) {
									detailInfo = contentValue;
								}
								
							}
						}
					}
				}
			}
					
		} catch (FactoryConfigurationError e) {
			e.printStackTrace();
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
		} catch (SAXException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return new EmergencyInfo(contentID,
								  generatedTime,
								  generator,
								  sourceContentID,
								  accidentTime,
								  accidentLatitude,
								  accidentLongitude,
								  accidentType,
								  detailInfo);
	}
}
