/*
 * Created on 2005/01/20
 *
 */
package jnet.hiromicam.properity;

import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * This class is for system property.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class SystemProperty {
	
	private static SystemProperty myProperty;
	
	/**
	 * port number for receiving infomation.
	 */
	public static final int PORT = 1631;
	
	/**
	 * IPAddress
	 */
	private String addr;
	
	/**
	 * Host Name
	 */
	private String hostName;
	
	/**
	 * Serial Port number for GPS receiver
	 */
	private String serialPortNumber = "COM1";
	
	/**
	 * This system log GPS Information or not.
	 */
	private boolean GpsInfoLogger = true;
	
	/**
	 * nobady can create instance of this class from a constractor.
	 * 
	 * @throws Exception
	 */
	private SystemProperty() {
		try {
			// get LocalHost infomation.
			InetAddress iAdder = InetAddress.getLocalHost();
			// set my IP Address.
			this.addr = iAdder.getHostAddress();
			// set my Hostname.
			hostName = iAdder.getHostName();
		} catch (UnknownHostException e) {
			System.out.println("Error : Acquisition of a LocalHost information goes wrong.");
			e.printStackTrace();
		}
	}
	
	/**
	 * This method is for getting myTerminalInfo instance.
	 * 
	 * @return MyProperty instance.
	 * @throws Exception
	 */
	public static synchronized SystemProperty getInstance() {
		if(myProperty == null) {
			myProperty = new SystemProperty();
		}
		return myProperty;
	}
	
	/**
	 * This method returns Serial Port Number.
	 * 
	 * @return Returns the serialPortNumber.
	 */
	public String getSerialPortNumber() {
		return serialPortNumber;
	}
	
	/**
	 * This method is for setting Serial Port Number.
	 * 
	 * @param serialPortNumber The serialPortNumber to set.
	 */
	public void setSerialPortNumber(String serialPortNumber) {
		this.serialPortNumber = serialPortNumber;
	}
	
	/**
	 * This method returns IP Address.
	 * 
	 * @return Returns the addr.
	 */
	public String getAddr() {
		return addr;
	}
	
	/**
	 * This method returns HostName.
	 * 
	 * @return Returns the name.
	 */
	public String getHostName() {
		return hostName;
	}
	
	/**
	 * This method returns whether this system taking log or not.
	 * <br>
	 * true:logging, false:no logging
	 * 
	 * @return Returns the gpsInfoLogger.
	 */
	public boolean isGpsInfoLogger() {
		return GpsInfoLogger;
	}
	
	/**
	 * This method is for setting whether this system taking log or not.
	 * <br>
	 * true:logging, false:no logging
	 * 
	 * @param gpsInfoLogger The gpsInfoLogger to set.
	 */
	public void setGpsInfoLogger(boolean gpsInfoLogger) {
		GpsInfoLogger = gpsInfoLogger;
	}
}
