/*
 * Created on 2005/01/23
 *
 */
package jnet.hiromicam.util.file;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Calendar;

/**
 * This class is for logging GPS Information form satellite in GGA format.
 * 
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class GpsInfoLogger {
	/**
	 * This is only instance of GpsInfoLogger.
	 */
	private static GpsInfoLogger gpsInfoLogger = new GpsInfoLogger();
	
	/**
	 * This is log size.
	 * If this value is 600, this system will have logging for 600 sec.
	 */
	private static int buffSize = 600;
	
	/**
	 * This is history of GPS Information.
	 */
	private ArrayList gpsInfoList = new ArrayList();
	
	/**
	 * nobady create instance from constractor.
	 *
	 */
	private GpsInfoLogger() {
		
	}
	
	/**
	 * This method reuturn instance of this class.
	 * 
	 * @return instance of this class.
	 */
	public static GpsInfoLogger getInstance(){
		return gpsInfoLogger;
	}
	
	/**
	 * This method returns buffer size.
	 * 
	 * @return Returns the buffSize.
	 */
	public static int getBuffSize() {
		return buffSize;
	}
	
	/**
	 * This method is for setting buffer size.
	 * unit of buff size is second.
	 * 
	 * @param buffSize The buffSize to set.
	 */
	public static void setBuffSize(int buffSize) {
		GpsInfoLogger.buffSize = buffSize;
	}
	
	// This method override javadoc of super class.
	public String toString() {
		String str = "";
		for (int i = 0; i < gpsInfoList.size(); i++) {
			str += (String)gpsInfoList.get(i) + "\n";
		}
		
		return str;
	}
	
	/**
	 * This method output log to file.
	 * 
	 * @param fileName file pass.
	 * @return true:success log to file, false:other.
	 */
	public boolean outputFile(String fileName) {
		String gga = "";
		
		try {
			BufferedWriter writer =
					new BufferedWriter(new FileWriter(fileName));
			
			// writing time.
			Calendar c = Calendar.getInstance();
			writer.write(c.getTime().toString() + "\n");
			
			for (int i = 0; i < gpsInfoList.size(); i++) {
				gga += (String)gpsInfoList.get(i) + "\n";
				writer.write(gga);
			}
			
			// close
			writer.close();
			return true;
			
		} catch (IOException e) {
			System.out.println("Error : IOException.");
			e.printStackTrace();
			return false;
		}
	}
	
	/**
	 * This method is for adding GPS Information to log.
	 * 
	 * @param str GGA format to log.
	 * @return true:success logging, false:other
	 */
	public boolean addGpsInfo(String str) {
		 if(gpsInfoList.size() < buffSize) {
		 	gpsInfoList.add(str);
		 	return true;
		 }
		 
		 // when buffere is full, this system fail to log.
		 return false;
	}
	
	/**
	 * This method clear Logger.
	 * 
	 * @return true:success logging, false:other
	 */
	public boolean clearGpsInfoLogger() {
		gpsInfoList.clear();
		return true;
	}
}
