/*
 * Created on 2005/01/25
 *
 */
package jnet.htk.gui;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import javax.swing.JTabbedPane;

import jnet.application.gui.MainWindow;
/**
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class HTKMainWindow extends JFrame {
	
	/**
	 * size of window
	 */
	public  static final int WINDOW_HEIGHT = 300;
	
	/**
	 * size of window
	 */
	public  static final int WINDOW_WIDTH = 500;
	
	/**
	 * This is a look and feel.
	 * <br>
	 * 0:Windows<br>
	 * 1:Metal<br>
	 * 2:GTK<br>
	 * 3:Motifi<br>
	 * 4:Mac<br>
	 */
	private String[] lookAndFeelStr = {"com.sun.java.swing.plaf.windows.WindowsLookAndFeel",
										"javax.swing.plaf.metal.MetalLookAndFeel",
									 	"com.sun.java.swing.plaf.gtk.GTKLookAndFeel",
										"com.sun.java.swing.plaf.motif.MotifLookAndFeel",
										"com.sun.java.swing.plaf.mac.MacLookAndFeel"
										
	};
	
	private javax.swing.JPanel jContentPane = null;

	private JTabbedPane jTabbedPane = null;
	private SimulationTabPanel simulationTabPanel = null;
	private FileManagerTabPanel fileManagerPanel = null;
	/**
	 * This is the default constructor
	 */
	public HTKMainWindow() {
		super();
		initialize();
	}
	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setSize(WINDOW_WIDTH,WINDOW_HEIGHT);
		this.setContentPane(getJContentPane());
		this.setTitle("Hiromicam Tool Kit");
		this.setResizable(false);
		// setting Look and Feel
		try {
			UIManager.setLookAndFeel(lookAndFeelStr[0]);
			SwingUtilities.updateComponentTreeUI(this);
		} catch (ClassNotFoundException e1) {
			
			e1.printStackTrace();
		} catch (InstantiationException e1) {
			
			e1.printStackTrace();
		} catch (IllegalAccessException e1) {
			
			e1.printStackTrace();
		} catch (UnsupportedLookAndFeelException e1) {
			
			e1.printStackTrace();
		}
		this.addWindowListener(
				new WindowAdapter() {
					public void windowClosing(WindowEvent e) {
						MainWindow.getHtkMainWindow().setVisible(false);
					}
				}
			);
	}
	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private javax.swing.JPanel getJContentPane() {
		if(jContentPane == null) {
			jContentPane = new javax.swing.JPanel();
			jContentPane.setLayout(new java.awt.BorderLayout());
			jContentPane.add(getJTabbedPane(), java.awt.BorderLayout.NORTH);
		}
		return jContentPane;
	}
	/**
	 * This method initializes jTabbedPane	
	 * 	
	 * @return javax.swing.JTabbedPane	
	 */    
	private JTabbedPane getJTabbedPane() {
		if (jTabbedPane == null) {
			jTabbedPane = new JTabbedPane();
			jTabbedPane.addTab("Simulation", null, getSimulationTabPanel(), null);
			jTabbedPane.addTab("FileManager", null, getFileManagerPanel(), null);
		}
		return jTabbedPane;
	}
	/**
	 * This method initializes simulationTabPanel	
	 * 	
	 * @return jnet.htk.gui.SimulationTabPanel	
	 */    
	private SimulationTabPanel getSimulationTabPanel() {
		if (simulationTabPanel == null) {
			simulationTabPanel = new SimulationTabPanel();
			simulationTabPanel.setName("Simulation");
			simulationTabPanel.setFont(new java.awt.Font("Dialog", java.awt.Font.PLAIN, 12));
		}
		return simulationTabPanel;
	}
	/**
	 * This method initializes fileManagerPanel	
	 * 	
	 * @return jnet.htk.gui.FileManagerPanel	
	 */    
	private FileManagerTabPanel getFileManagerPanel() {
		if (fileManagerPanel == null) {
			fileManagerPanel = new FileManagerTabPanel();
		}
		return fileManagerPanel;
	}
   }
