/*
 * Created on 2005/01/25
 *
 */
package jnet.htk.sim;

import java.io.IOException;
import java.util.ArrayList;

import jnet.application.gui.Viewer;
import jnet.gps.process.SimpleDirectionCalculationMethod;
import jnet.gps.process.SimpleSpeedCalculationMethod;
import jnet.hiromicam.buff.FirstLevelInfoBuff;
import jnet.hiromicam.buff.MyTerminal;
import jnet.hiromicam.msg.FirstLevelInfo;
import jnet.hiromicam.msg.factory.FirstLevelInfoFactory;
import jnet.htk.sorce.SourceData;

/**
 * @author Kazuya Sakai
 * @version 1.0
 * @since jdk 1.4.2
 */
public class FirstLevelInfoSimulator implements Runnable {
	/**
	 * This value is factory class.
	 * You can chose calculation method of speed and direction.
	 */
	private static FirstLevelInfoFactory factory =
			new FirstLevelInfoFactory(new SimpleSpeedCalculationMethod(),
									  new SimpleDirectionCalculationMethod());
	
	private String myFile;
	
	private ArrayList targetFileList;
	
	private int sleepTime = 100;
	
	/**
	 * This is a default constractor.
	 * 
	 * @param myFile source file name of my information.
	 * @param targetFileList source file name list of target information.
	 */
	public FirstLevelInfoSimulator(String myFile, ArrayList targetFileList) {
		this.myFile = myFile;
		this.targetFileList = targetFileList;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Runnable#run()
	 */
	public void run() {
		try {
			SourceData source = new SourceData(myFile, targetFileList);
			int mySourceScale = source.getMySourceList().size();
			
			for (int i = 0; i < mySourceScale; i++) {
				// creating high level information.
				FirstLevelInfo myMsg =
						factory.createFirstLevelInfo((String)source.getMySourceList().get(i));
				// logging
				MyTerminal.getInstance().addFirstLevelInfo(myMsg);
				
				 // target.
				for (int j = 0; j < targetFileList.size(); j++) {
					ArrayList firstLevelInfoList = (ArrayList)(source.getTargetList()).get(j);
					FirstLevelInfo targetMsg =
							factory.createFirstLevelInfo((String)firstLevelInfoList.get(i));
					
					// logging
					FirstLevelInfoBuff.getInstance().addFirstLevelInfo("target-" + j,"target-" + j,targetMsg);
				}
				
				
				// view
				Viewer.getInstance().repaint();
				
				// sleep
				Thread.sleep(sleepTime);
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @param sleepTime The sleepTime to set.
	 */
	public void setSleepTime(int sleepTime) {
		this.sleepTime = sleepTime;
	}
}
